Name:          forbidden-apis
Version:       2.5
Release:       %mkrel 4
Group:         Development/Java
Summary:       Policeman's Forbidden API Checker
License:       ASL 2.0
URL:           https://github.com/policeman-tools/forbidden-apis
Source0:       https://github.com/policeman-tools/%{name}/archive/%{version}/%{name}-%{version}.tar.gz

# Avoid bundling deps
Patch0:        avoid-jarjar-bundling.patch

# Port to latest versions of gradle and maven in Fedora
Patch1:        fix-gradle-maven-build.patch

Patch2:	       forbidden-apis-2.5-remove-ant-contrib.patch

BuildArch:     noarch

BuildRequires: ivy-local
BuildRequires: maven-local
BuildRequires: ant
BuildRequires: ant-antunit
BuildRequires: ant-junit
BuildRequires: objectweb-asm
BuildRequires: plexus-utils
BuildRequires: maven-plugin-plugin
BuildRequires: sonatype-oss-parent

%description
Allows to parse Java byte code to find invocations of method/class/field
signatures and fail build (Apache Ant, Apache Maven, or Gradle).

%package javadoc
Summary: Javadoc for %{name}

%description javadoc
This package contains API documentation for %{name}.

%prep
%setup -q
%patch0
%patch1
%patch2 -p1

find . -name "*.jar" -print -delete
find . -name "*.class" -print -delete

# Use system ivy settings
sed -i -e '/ivy:configure/d' build.xml

# Can't use missing maven-ant-tasks
%pom_xpath_remove "target/artifact:pom" build.xml
%pom_xpath_remove "target/artifact:mvn" build.xml
%pom_xpath_remove "target/artifact:install" build.xml
%pom_xpath_inject "target[@name='maven-descriptor']" \
"<exec executable='xmvn'>
  <arg value=\"-o\"/>
  <arg value=\"-f\"/>
  <arg value=\"\${maven-build-dir}/pom-build.xml\"/>
  <arg value=\"plugin:helpmojo\"/>
  <arg value=\"plugin:descriptor\"/>
  <arg value=\"plugin:report\"/>
  <arg value=\"-Dinjected.src.dir=src/main/java\"/>
  <arg value=\"-Dinjected.output.dir=../../build/main\"/>
  <arg value=\"-Dinjected.build.dir=\${maven-build-dir}\"/>
  <arg value=\"-Dinjected.maven-plugin-plugin.version=\${maven-plugin-plugin.version}\"/>
</exec>" build.xml
sed -i -e '/maven-ant-tasks/d' ivy.xml
sed -i -e '/uri="antlib:org.apache.maven.artifact.ant/d' build.xml

# Don't need to run RAT for RPM builds
sed -i -e '/apache-rat/d' ivy.xml
sed -i -e '/uri="antlib:org.apache.rat.anttasks/d' build.xml
rm -rf src/main/java/de/thetaphi/forbiddenapis/gradle src/test/gradle

%build
ant -Divy.mode=local jar

%install
# Add deps on unbundled jars, taken from ivy.xml
%pom_add_dep org.apache.ant:ant:1.7.0:provided build/maven/pom-deploy.xml
%pom_add_dep org.ow2.asm:asm:6.1.1 build/maven/pom-deploy.xml
%pom_add_dep org.ow2.asm:asm-commons:6.1.1 build/maven/pom-deploy.xml
%pom_add_dep org.codehaus.plexus:plexus-utils:1.1 build/maven/pom-deploy.xml
%pom_add_dep commons-cli:commons-cli:1.3.1 build/maven/pom-deploy.xml

# Install maven artifacts
%mvn_artifact build/maven/pom-deploy.xml dist/forbiddenapis-2.5.jar
%mvn_install -J build/docs

# Install ant configuration
mkdir -p %{buildroot}%{_sysconfdir}/ant.d
echo "%{name} ant apache-commons-cli objectweb-asm/asm objectweb-asm/asm-commons plexus/utils" > %{name}-ant
install -pm 644 %{name}-ant %{buildroot}%{_sysconfdir}/ant.d/%{name}

%files -f .mfiles
%config(noreplace) %{_sysconfdir}/ant.d/%{name}
%license LICENSE.txt NOTICE.txt
%doc README.md



%changelog
* Thu Jan 07 2021 neoclust <neoclust> 2.5-4.mga8
+ Revision: 1669705
- Remove ant-contrib as BR ( add P2 )

* Sat Sep 05 2020 daviddavid <daviddavid> 2.5-3.mga8
+ Revision: 1622294
- Rebuilt for JDK-11
- compile without gradle and docs

* Fri Feb 14 2020 umeabot <umeabot> 2.5-2.mga8
+ Revision: 1520847
- Mageia 8 Mass Rebuild

* Tue Dec 11 2018 daviddavid <daviddavid> 2.5-1.mga7
+ Revision: 1340128
- new version: 2.5 (sync with fc29)

* Tue Sep 18 2018 umeabot <umeabot> 1.7-7.mga7
+ Revision: 1261834
- Mageia 7 Mass Rebuild

* Wed May 17 2017 neoclust <neoclust> 1.7-6.mga6
+ Revision: 1102544
- Fix BuildRequires
- Add missing BuildRequires to fix FTBFS

* Wed Mar 02 2016 neoclust <neoclust> 1.7-5.mga6
+ Revision: 982562
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 1.7-4.mga6
+ Revision: 976218
- First rebuild of the java stack
- sync package forbidden-apis with fedora
- imported package forbidden-apis


* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.7-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.7-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue Feb 03 2015 Zdenek Zambersky <zzambers@redhat.com> 1.7-1
- updated to version 1.7
- version tag in custom pom.xml is now generated automaticaly
* Fri Oct 11 2013 gil cattaneo <puntogil@libero.it> 1.3-1
- initial rpm
